# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_spot_exchange_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*exchange/injective_spot_exchange_rpc.proto\x12\x1binjective_spot_exchange_rpc\"\x9e\x01\n\x0eMarketsRequest\x12#\n\rmarket_status\x18\x01 \x01(\tR\x0cmarketStatus\x12\x1d\n\nbase_denom\x18\x02 \x01(\tR\tbaseDenom\x12\x1f\n\x0bquote_denom\x18\x03 \x01(\tR\nquoteDenom\x12\'\n\x0fmarket_statuses\x18\x04 \x03(\tR\x0emarketStatuses\"X\n\x0fMarketsResponse\x12\x45\n\x07markets\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfoR\x07markets\"\xd1\x04\n\x0eSpotMarketInfo\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rmarket_status\x18\x02 \x01(\tR\x0cmarketStatus\x12\x16\n\x06ticker\x18\x03 \x01(\tR\x06ticker\x12\x1d\n\nbase_denom\x18\x04 \x01(\tR\tbaseDenom\x12N\n\x0f\x62\x61se_token_meta\x18\x05 \x01(\x0b\x32&.injective_spot_exchange_rpc.TokenMetaR\rbaseTokenMeta\x12\x1f\n\x0bquote_denom\x18\x06 \x01(\tR\nquoteDenom\x12P\n\x10quote_token_meta\x18\x07 \x01(\x0b\x32&.injective_spot_exchange_rpc.TokenMetaR\x0equoteTokenMeta\x12$\n\x0emaker_fee_rate\x18\x08 \x01(\tR\x0cmakerFeeRate\x12$\n\x0etaker_fee_rate\x18\t \x01(\tR\x0ctakerFeeRate\x12\x30\n\x14service_provider_fee\x18\n \x01(\tR\x12serviceProviderFee\x12-\n\x13min_price_tick_size\x18\x0b \x01(\tR\x10minPriceTickSize\x12\x33\n\x16min_quantity_tick_size\x18\x0c \x01(\tR\x13minQuantityTickSize\x12!\n\x0cmin_notional\x18\r \x01(\tR\x0bminNotional\"\xa0\x01\n\tTokenMeta\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06symbol\x18\x03 \x01(\tR\x06symbol\x12\x12\n\x04logo\x18\x04 \x01(\tR\x04logo\x12\x1a\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11R\x08\x64\x65\x63imals\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\",\n\rMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"U\n\x0eMarketResponse\x12\x43\n\x06market\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfoR\x06market\"5\n\x14StreamMarketsRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"\xa1\x01\n\x15StreamMarketsResponse\x12\x43\n\x06market\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfoR\x06market\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"G\n\x12OrderbookV2Request\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x14\n\x05\x64\x65pth\x18\x02 \x01(\x11R\x05\x64\x65pth\"f\n\x13OrderbookV2Response\x12O\n\torderbook\x18\x01 \x01(\x0b\x32\x31.injective_spot_exchange_rpc.SpotLimitOrderbookV2R\torderbook\"\xcc\x01\n\x14SpotLimitOrderbookV2\x12;\n\x04\x62uys\x18\x01 \x03(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevelR\x04\x62uys\x12=\n\x05sells\x18\x02 \x03(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevelR\x05sells\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\\\n\nPriceLevel\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\tR\x08quantity\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"J\n\x13OrderbooksV2Request\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\x12\x14\n\x05\x64\x65pth\x18\x02 \x01(\x11R\x05\x64\x65pth\"o\n\x14OrderbooksV2Response\x12W\n\norderbooks\x18\x01 \x03(\x0b\x32\x37.injective_spot_exchange_rpc.SingleSpotLimitOrderbookV2R\norderbooks\"\x8a\x01\n\x1aSingleSpotLimitOrderbookV2\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12O\n\torderbook\x18\x02 \x01(\x0b\x32\x31.injective_spot_exchange_rpc.SpotLimitOrderbookV2R\torderbook\"9\n\x18StreamOrderbookV2Request\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"\xce\x01\n\x19StreamOrderbookV2Response\x12O\n\torderbook\x18\x01 \x01(\x0b\x32\x31.injective_spot_exchange_rpc.SpotLimitOrderbookV2R\torderbook\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\x12\x1b\n\tmarket_id\x18\x04 \x01(\tR\x08marketId\"=\n\x1cStreamOrderbookUpdateRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"\xed\x01\n\x1dStreamOrderbookUpdateResponse\x12j\n\x17orderbook_level_updates\x18\x01 \x01(\x0b\x32\x32.injective_spot_exchange_rpc.OrderbookLevelUpdatesR\x15orderbookLevelUpdates\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\x12\x1b\n\tmarket_id\x18\x04 \x01(\tR\x08marketId\"\xf7\x01\n\x15OrderbookLevelUpdates\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12\x41\n\x04\x62uys\x18\x03 \x03(\x0b\x32-.injective_spot_exchange_rpc.PriceLevelUpdateR\x04\x62uys\x12\x43\n\x05sells\x18\x04 \x03(\x0b\x32-.injective_spot_exchange_rpc.PriceLevelUpdateR\x05sells\x12\x1d\n\nupdated_at\x18\x05 \x01(\x12R\tupdatedAt\"\x7f\n\x10PriceLevelUpdate\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\tR\x08quantity\x12\x1b\n\tis_active\x18\x03 \x01(\x08R\x08isActive\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\x83\x03\n\rOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x04 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x05 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x06 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x07 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\x08 \x03(\tR\tmarketIds\x12)\n\x10include_inactive\x18\t \x01(\x08R\x0fincludeInactive\x12\x36\n\x17subaccount_total_orders\x18\n \x01(\x08R\x15subaccountTotalOrders\x12\x19\n\x08trade_id\x18\x0b \x01(\tR\x07tradeId\x12\x10\n\x03\x63id\x18\x0c \x01(\tR\x03\x63id\"\x92\x01\n\x0eOrdersResponse\x12\x43\n\x06orders\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrderR\x06orders\x12;\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.PagingR\x06paging\"\xb8\x03\n\x0eSpotLimitOrder\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x14\n\x05price\x18\x05 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x06 \x01(\tR\x08quantity\x12+\n\x11unfilled_quantity\x18\x07 \x01(\tR\x10unfilledQuantity\x12#\n\rtrigger_price\x18\x08 \x01(\tR\x0ctriggerPrice\x12#\n\rfee_recipient\x18\t \x01(\tR\x0c\x66\x65\x65Recipient\x12\x14\n\x05state\x18\n \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0b \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0c \x01(\x12R\tupdatedAt\x12\x17\n\x07tx_hash\x18\r \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\"\x86\x01\n\x06Paging\x12\x14\n\x05total\x18\x01 \x01(\x12R\x05total\x12\x12\n\x04\x66rom\x18\x02 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x03 \x01(\x11R\x02to\x12.\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12R\x11\x63ountBySubaccount\x12\x12\n\x04next\x18\x05 \x03(\tR\x04next\"\x89\x03\n\x13StreamOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x04 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x05 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x06 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x07 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\x08 \x03(\tR\tmarketIds\x12)\n\x10include_inactive\x18\t \x01(\x08R\x0fincludeInactive\x12\x36\n\x17subaccount_total_orders\x18\n \x01(\x08R\x15subaccountTotalOrders\x12\x19\n\x08trade_id\x18\x0b \x01(\tR\x07tradeId\x12\x10\n\x03\x63id\x18\x0c \x01(\tR\x03\x63id\"\x9e\x01\n\x14StreamOrdersResponse\x12\x41\n\x05order\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrderR\x05order\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\xe4\x03\n\rTradesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\x8d\x01\n\x0eTradesResponse\x12>\n\x06trades\x18\x01 \x03(\x0b\x32&.injective_spot_exchange_rpc.SpotTradeR\x06trades\x12;\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.PagingR\x06paging\"\xb2\x03\n\tSpotTrade\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x30\n\x14trade_execution_type\x18\x04 \x01(\tR\x12tradeExecutionType\x12\'\n\x0ftrade_direction\x18\x05 \x01(\tR\x0etradeDirection\x12=\n\x05price\x18\x06 \x01(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevelR\x05price\x12\x10\n\x03\x66\x65\x65\x18\x07 \x01(\tR\x03\x66\x65\x65\x12\x1f\n\x0b\x65xecuted_at\x18\x08 \x01(\x12R\nexecutedAt\x12#\n\rfee_recipient\x18\t \x01(\tR\x0c\x66\x65\x65Recipient\x12\x19\n\x08trade_id\x18\n \x01(\tR\x07tradeId\x12%\n\x0e\x65xecution_side\x18\x0b \x01(\tR\rexecutionSide\x12\x10\n\x03\x63id\x18\x0c \x01(\tR\x03\x63id\"\xea\x03\n\x13StreamTradesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\x99\x01\n\x14StreamTradesResponse\x12<\n\x05trade\x18\x01 \x01(\x0b\x32&.injective_spot_exchange_rpc.SpotTradeR\x05trade\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\xe6\x03\n\x0fTradesV2Request\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\x8f\x01\n\x10TradesV2Response\x12>\n\x06trades\x18\x01 \x03(\x0b\x32&.injective_spot_exchange_rpc.SpotTradeR\x06trades\x12;\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.PagingR\x06paging\"\xec\x03\n\x15StreamTradesV2Request\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\x9b\x01\n\x16StreamTradesV2Response\x12<\n\x05trade\x18\x01 \x01(\x0b\x32&.injective_spot_exchange_rpc.SpotTradeR\x05trade\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\x89\x01\n\x1bSubaccountOrdersListRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\"\xa0\x01\n\x1cSubaccountOrdersListResponse\x12\x43\n\x06orders\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrderR\x06orders\x12;\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.PagingR\x06paging\"\xce\x01\n\x1bSubaccountTradesListRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_type\x18\x03 \x01(\tR\rexecutionType\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\"^\n\x1cSubaccountTradesListResponse\x12>\n\x06trades\x18\x01 \x03(\x0b\x32&.injective_spot_exchange_rpc.SpotTradeR\x06trades\"\xb6\x03\n\x14OrdersHistoryRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\x12\x1f\n\x0border_types\x18\x05 \x03(\tR\norderTypes\x12\x1c\n\tdirection\x18\x06 \x01(\tR\tdirection\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x14\n\x05state\x18\t \x01(\tR\x05state\x12\'\n\x0f\x65xecution_types\x18\n \x03(\tR\x0e\x65xecutionTypes\x12\x1d\n\nmarket_ids\x18\x0b \x03(\tR\tmarketIds\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12.\n\x13\x61\x63tive_markets_only\x18\r \x01(\x08R\x11\x61\x63tiveMarketsOnly\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\"\x9b\x01\n\x15OrdersHistoryResponse\x12\x45\n\x06orders\x18\x01 \x03(\x0b\x32-.injective_spot_exchange_rpc.SpotOrderHistoryR\x06orders\x12;\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.PagingR\x06paging\"\xf3\x03\n\x10SpotOrderHistory\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1b\n\tis_active\x18\x03 \x01(\x08R\x08isActive\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12%\n\x0e\x65xecution_type\x18\x05 \x01(\tR\rexecutionType\x12\x1d\n\norder_type\x18\x06 \x01(\tR\torderType\x12\x14\n\x05price\x18\x07 \x01(\tR\x05price\x12#\n\rtrigger_price\x18\x08 \x01(\tR\x0ctriggerPrice\x12\x1a\n\x08quantity\x18\t \x01(\tR\x08quantity\x12\'\n\x0f\x66illed_quantity\x18\n \x01(\tR\x0e\x66illedQuantity\x12\x14\n\x05state\x18\x0b \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\r \x01(\x12R\tupdatedAt\x12\x1c\n\tdirection\x18\x0e \x01(\tR\tdirection\x12\x17\n\x07tx_hash\x18\x0f \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x10 \x01(\tR\x03\x63id\"\xdc\x01\n\x1aStreamOrdersHistoryRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1f\n\x0border_types\x18\x03 \x03(\tR\norderTypes\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x14\n\x05state\x18\x05 \x01(\tR\x05state\x12\'\n\x0f\x65xecution_types\x18\x06 \x03(\tR\x0e\x65xecutionTypes\"\xa7\x01\n\x1bStreamOrdersHistoryResponse\x12\x43\n\x05order\x18\x01 \x01(\x0b\x32-.injective_spot_exchange_rpc.SpotOrderHistoryR\x05order\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\xc7\x01\n\x18\x41tomicSwapHistoryRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12\x12\n\x04skip\x18\x03 \x01(\x11R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\x12\x1f\n\x0b\x66rom_number\x18\x05 \x01(\x11R\nfromNumber\x12\x1b\n\tto_number\x18\x06 \x01(\x11R\x08toNumber\"\x95\x01\n\x19\x41tomicSwapHistoryResponse\x12;\n\x06paging\x18\x01 \x01(\x0b\x32#.injective_spot_exchange_rpc.PagingR\x06paging\x12;\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\'.injective_spot_exchange_rpc.AtomicSwapR\x04\x64\x61ta\"\xe0\x03\n\nAtomicSwap\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x14\n\x05route\x18\x02 \x01(\tR\x05route\x12\x42\n\x0bsource_coin\x18\x03 \x01(\x0b\x32!.injective_spot_exchange_rpc.CoinR\nsourceCoin\x12>\n\tdest_coin\x18\x04 \x01(\x0b\x32!.injective_spot_exchange_rpc.CoinR\x08\x64\x65stCoin\x12\x35\n\x04\x66\x65\x65s\x18\x05 \x03(\x0b\x32!.injective_spot_exchange_rpc.CoinR\x04\x66\x65\x65s\x12)\n\x10\x63ontract_address\x18\x06 \x01(\tR\x0f\x63ontractAddress\x12&\n\x0findex_by_sender\x18\x07 \x01(\x11R\rindexBySender\x12\x37\n\x18index_by_sender_contract\x18\x08 \x01(\x11R\x15indexBySenderContract\x12\x17\n\x07tx_hash\x18\t \x01(\tR\x06txHash\x12\x1f\n\x0b\x65xecuted_at\x18\n \x01(\x12R\nexecutedAt\x12#\n\rrefund_amount\x18\x0b \x01(\tR\x0crefundAmount\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue2\x9e\x11\n\x18InjectiveSpotExchangeRPC\x12\x64\n\x07Markets\x12+.injective_spot_exchange_rpc.MarketsRequest\x1a,.injective_spot_exchange_rpc.MarketsResponse\x12\x61\n\x06Market\x12*.injective_spot_exchange_rpc.MarketRequest\x1a+.injective_spot_exchange_rpc.MarketResponse\x12x\n\rStreamMarkets\x12\x31.injective_spot_exchange_rpc.StreamMarketsRequest\x1a\x32.injective_spot_exchange_rpc.StreamMarketsResponse0\x01\x12p\n\x0bOrderbookV2\x12/.injective_spot_exchange_rpc.OrderbookV2Request\x1a\x30.injective_spot_exchange_rpc.OrderbookV2Response\x12s\n\x0cOrderbooksV2\x12\x30.injective_spot_exchange_rpc.OrderbooksV2Request\x1a\x31.injective_spot_exchange_rpc.OrderbooksV2Response\x12\x84\x01\n\x11StreamOrderbookV2\x12\x35.injective_spot_exchange_rpc.StreamOrderbookV2Request\x1a\x36.injective_spot_exchange_rpc.StreamOrderbookV2Response0\x01\x12\x90\x01\n\x15StreamOrderbookUpdate\x12\x39.injective_spot_exchange_rpc.StreamOrderbookUpdateRequest\x1a:.injective_spot_exchange_rpc.StreamOrderbookUpdateResponse0\x01\x12\x61\n\x06Orders\x12*.injective_spot_exchange_rpc.OrdersRequest\x1a+.injective_spot_exchange_rpc.OrdersResponse\x12u\n\x0cStreamOrders\x12\x30.injective_spot_exchange_rpc.StreamOrdersRequest\x1a\x31.injective_spot_exchange_rpc.StreamOrdersResponse0\x01\x12\x61\n\x06Trades\x12*.injective_spot_exchange_rpc.TradesRequest\x1a+.injective_spot_exchange_rpc.TradesResponse\x12u\n\x0cStreamTrades\x12\x30.injective_spot_exchange_rpc.StreamTradesRequest\x1a\x31.injective_spot_exchange_rpc.StreamTradesResponse0\x01\x12g\n\x08TradesV2\x12,.injective_spot_exchange_rpc.TradesV2Request\x1a-.injective_spot_exchange_rpc.TradesV2Response\x12{\n\x0eStreamTradesV2\x12\x32.injective_spot_exchange_rpc.StreamTradesV2Request\x1a\x33.injective_spot_exchange_rpc.StreamTradesV2Response0\x01\x12\x8b\x01\n\x14SubaccountOrdersList\x12\x38.injective_spot_exchange_rpc.SubaccountOrdersListRequest\x1a\x39.injective_spot_exchange_rpc.SubaccountOrdersListResponse\x12\x8b\x01\n\x14SubaccountTradesList\x12\x38.injective_spot_exchange_rpc.SubaccountTradesListRequest\x1a\x39.injective_spot_exchange_rpc.SubaccountTradesListResponse\x12v\n\rOrdersHistory\x12\x31.injective_spot_exchange_rpc.OrdersHistoryRequest\x1a\x32.injective_spot_exchange_rpc.OrdersHistoryResponse\x12\x8a\x01\n\x13StreamOrdersHistory\x12\x37.injective_spot_exchange_rpc.StreamOrdersHistoryRequest\x1a\x38.injective_spot_exchange_rpc.StreamOrdersHistoryResponse0\x01\x12\x82\x01\n\x11\x41tomicSwapHistory\x12\x35.injective_spot_exchange_rpc.AtomicSwapHistoryRequest\x1a\x36.injective_spot_exchange_rpc.AtomicSwapHistoryResponseB\xe0\x01\n\x1f\x63om.injective_spot_exchange_rpcB\x1dInjectiveSpotExchangeRpcProtoP\x01Z\x1e/injective_spot_exchange_rpcpb\xa2\x02\x03IXX\xaa\x02\x18InjectiveSpotExchangeRpc\xca\x02\x18InjectiveSpotExchangeRpc\xe2\x02$InjectiveSpotExchangeRpc\\GPBMetadata\xea\x02\x18InjectiveSpotExchangeRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_spot_exchange_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.injective_spot_exchange_rpcB\035InjectiveSpotExchangeRpcProtoP\001Z\036/injective_spot_exchange_rpcpb\242\002\003IXX\252\002\030InjectiveSpotExchangeRpc\312\002\030InjectiveSpotExchangeRpc\342\002$InjectiveSpotExchangeRpc\\GPBMetadata\352\002\030InjectiveSpotExchangeRpc'
  _globals['_MARKETSREQUEST']._serialized_start=76
  _globals['_MARKETSREQUEST']._serialized_end=234
  _globals['_MARKETSRESPONSE']._serialized_start=236
  _globals['_MARKETSRESPONSE']._serialized_end=324
  _globals['_SPOTMARKETINFO']._serialized_start=327
  _globals['_SPOTMARKETINFO']._serialized_end=920
  _globals['_TOKENMETA']._serialized_start=923
  _globals['_TOKENMETA']._serialized_end=1083
  _globals['_MARKETREQUEST']._serialized_start=1085
  _globals['_MARKETREQUEST']._serialized_end=1129
  _globals['_MARKETRESPONSE']._serialized_start=1131
  _globals['_MARKETRESPONSE']._serialized_end=1216
  _globals['_STREAMMARKETSREQUEST']._serialized_start=1218
  _globals['_STREAMMARKETSREQUEST']._serialized_end=1271
  _globals['_STREAMMARKETSRESPONSE']._serialized_start=1274
  _globals['_STREAMMARKETSRESPONSE']._serialized_end=1435
  _globals['_ORDERBOOKV2REQUEST']._serialized_start=1437
  _globals['_ORDERBOOKV2REQUEST']._serialized_end=1508
  _globals['_ORDERBOOKV2RESPONSE']._serialized_start=1510
  _globals['_ORDERBOOKV2RESPONSE']._serialized_end=1612
  _globals['_SPOTLIMITORDERBOOKV2']._serialized_start=1615
  _globals['_SPOTLIMITORDERBOOKV2']._serialized_end=1819
  _globals['_PRICELEVEL']._serialized_start=1821
  _globals['_PRICELEVEL']._serialized_end=1913
  _globals['_ORDERBOOKSV2REQUEST']._serialized_start=1915
  _globals['_ORDERBOOKSV2REQUEST']._serialized_end=1989
  _globals['_ORDERBOOKSV2RESPONSE']._serialized_start=1991
  _globals['_ORDERBOOKSV2RESPONSE']._serialized_end=2102
  _globals['_SINGLESPOTLIMITORDERBOOKV2']._serialized_start=2105
  _globals['_SINGLESPOTLIMITORDERBOOKV2']._serialized_end=2243
  _globals['_STREAMORDERBOOKV2REQUEST']._serialized_start=2245
  _globals['_STREAMORDERBOOKV2REQUEST']._serialized_end=2302
  _globals['_STREAMORDERBOOKV2RESPONSE']._serialized_start=2305
  _globals['_STREAMORDERBOOKV2RESPONSE']._serialized_end=2511
  _globals['_STREAMORDERBOOKUPDATEREQUEST']._serialized_start=2513
  _globals['_STREAMORDERBOOKUPDATEREQUEST']._serialized_end=2574
  _globals['_STREAMORDERBOOKUPDATERESPONSE']._serialized_start=2577
  _globals['_STREAMORDERBOOKUPDATERESPONSE']._serialized_end=2814
  _globals['_ORDERBOOKLEVELUPDATES']._serialized_start=2817
  _globals['_ORDERBOOKLEVELUPDATES']._serialized_end=3064
  _globals['_PRICELEVELUPDATE']._serialized_start=3066
  _globals['_PRICELEVELUPDATE']._serialized_end=3193
  _globals['_ORDERSREQUEST']._serialized_start=3196
  _globals['_ORDERSREQUEST']._serialized_end=3583
  _globals['_ORDERSRESPONSE']._serialized_start=3586
  _globals['_ORDERSRESPONSE']._serialized_end=3732
  _globals['_SPOTLIMITORDER']._serialized_start=3735
  _globals['_SPOTLIMITORDER']._serialized_end=4175
  _globals['_PAGING']._serialized_start=4178
  _globals['_PAGING']._serialized_end=4312
  _globals['_STREAMORDERSREQUEST']._serialized_start=4315
  _globals['_STREAMORDERSREQUEST']._serialized_end=4708
  _globals['_STREAMORDERSRESPONSE']._serialized_start=4711
  _globals['_STREAMORDERSRESPONSE']._serialized_end=4869
  _globals['_TRADESREQUEST']._serialized_start=4872
  _globals['_TRADESREQUEST']._serialized_end=5356
  _globals['_TRADESRESPONSE']._serialized_start=5359
  _globals['_TRADESRESPONSE']._serialized_end=5500
  _globals['_SPOTTRADE']._serialized_start=5503
  _globals['_SPOTTRADE']._serialized_end=5937
  _globals['_STREAMTRADESREQUEST']._serialized_start=5940
  _globals['_STREAMTRADESREQUEST']._serialized_end=6430
  _globals['_STREAMTRADESRESPONSE']._serialized_start=6433
  _globals['_STREAMTRADESRESPONSE']._serialized_end=6586
  _globals['_TRADESV2REQUEST']._serialized_start=6589
  _globals['_TRADESV2REQUEST']._serialized_end=7075
  _globals['_TRADESV2RESPONSE']._serialized_start=7078
  _globals['_TRADESV2RESPONSE']._serialized_end=7221
  _globals['_STREAMTRADESV2REQUEST']._serialized_start=7224
  _globals['_STREAMTRADESV2REQUEST']._serialized_end=7716
  _globals['_STREAMTRADESV2RESPONSE']._serialized_start=7719
  _globals['_STREAMTRADESV2RESPONSE']._serialized_end=7874
  _globals['_SUBACCOUNTORDERSLISTREQUEST']._serialized_start=7877
  _globals['_SUBACCOUNTORDERSLISTREQUEST']._serialized_end=8014
  _globals['_SUBACCOUNTORDERSLISTRESPONSE']._serialized_start=8017
  _globals['_SUBACCOUNTORDERSLISTRESPONSE']._serialized_end=8177
  _globals['_SUBACCOUNTTRADESLISTREQUEST']._serialized_start=8180
  _globals['_SUBACCOUNTTRADESLISTREQUEST']._serialized_end=8386
  _globals['_SUBACCOUNTTRADESLISTRESPONSE']._serialized_start=8388
  _globals['_SUBACCOUNTTRADESLISTRESPONSE']._serialized_end=8482
  _globals['_ORDERSHISTORYREQUEST']._serialized_start=8485
  _globals['_ORDERSHISTORYREQUEST']._serialized_end=8923
  _globals['_ORDERSHISTORYRESPONSE']._serialized_start=8926
  _globals['_ORDERSHISTORYRESPONSE']._serialized_end=9081
  _globals['_SPOTORDERHISTORY']._serialized_start=9084
  _globals['_SPOTORDERHISTORY']._serialized_end=9583
  _globals['_STREAMORDERSHISTORYREQUEST']._serialized_start=9586
  _globals['_STREAMORDERSHISTORYREQUEST']._serialized_end=9806
  _globals['_STREAMORDERSHISTORYRESPONSE']._serialized_start=9809
  _globals['_STREAMORDERSHISTORYRESPONSE']._serialized_end=9976
  _globals['_ATOMICSWAPHISTORYREQUEST']._serialized_start=9979
  _globals['_ATOMICSWAPHISTORYREQUEST']._serialized_end=10178
  _globals['_ATOMICSWAPHISTORYRESPONSE']._serialized_start=10181
  _globals['_ATOMICSWAPHISTORYRESPONSE']._serialized_end=10330
  _globals['_ATOMICSWAP']._serialized_start=10333
  _globals['_ATOMICSWAP']._serialized_end=10813
  _globals['_COIN']._serialized_start=10815
  _globals['_COIN']._serialized_end=10896
  _globals['_INJECTIVESPOTEXCHANGERPC']._serialized_start=10899
  _globals['_INJECTIVESPOTEXCHANGERPC']._serialized_end=13105
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_auction_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_auction_rpc.proto\x12\x15injective_auction_rpc\".\n\x16\x41uctionEndpointRequest\x12\x14\n\x05round\x18\x01 \x01(\x12R\x05round\"\x83\x01\n\x17\x41uctionEndpointResponse\x12\x38\n\x07\x61uction\x18\x01 \x01(\x0b\x32\x1e.injective_auction_rpc.AuctionR\x07\x61uction\x12.\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x1a.injective_auction_rpc.BidR\x04\x62ids\"\xde\x01\n\x07\x41uction\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x33\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32\x1b.injective_auction_rpc.CoinR\x06\x62\x61sket\x12,\n\x12winning_bid_amount\x18\x03 \x01(\tR\x10winningBidAmount\x12\x14\n\x05round\x18\x04 \x01(\x04R\x05round\x12#\n\rend_timestamp\x18\x05 \x01(\x12R\x0c\x65ndTimestamp\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue\"S\n\x03\x42id\x12\x16\n\x06\x62idder\x18\x01 \x01(\tR\x06\x62idder\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\x11\n\x0f\x41uctionsRequest\"N\n\x10\x41uctionsResponse\x12:\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\x1e.injective_auction_rpc.AuctionR\x08\x61uctions\"\x13\n\x11StreamBidsRequest\"\x7f\n\x12StreamBidsResponse\x12\x16\n\x06\x62idder\x18\x01 \x01(\tR\x06\x62idder\x12\x1d\n\nbid_amount\x18\x02 \x01(\tR\tbidAmount\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\x19\n\x17InjBurntEndpointRequest\"B\n\x18InjBurntEndpointResponse\x12&\n\x0ftotal_inj_burnt\x18\x01 \x01(\tR\rtotalInjBurnt2\xbe\x03\n\x13InjectiveAuctionRPC\x12p\n\x0f\x41uctionEndpoint\x12-.injective_auction_rpc.AuctionEndpointRequest\x1a..injective_auction_rpc.AuctionEndpointResponse\x12[\n\x08\x41uctions\x12&.injective_auction_rpc.AuctionsRequest\x1a\'.injective_auction_rpc.AuctionsResponse\x12\x63\n\nStreamBids\x12(.injective_auction_rpc.StreamBidsRequest\x1a).injective_auction_rpc.StreamBidsResponse0\x01\x12s\n\x10InjBurntEndpoint\x12..injective_auction_rpc.InjBurntEndpointRequest\x1a/.injective_auction_rpc.InjBurntEndpointResponseB\xbb\x01\n\x19\x63om.injective_auction_rpcB\x18InjectiveAuctionRpcProtoP\x01Z\x18/injective_auction_rpcpb\xa2\x02\x03IXX\xaa\x02\x13InjectiveAuctionRpc\xca\x02\x13InjectiveAuctionRpc\xe2\x02\x1fInjectiveAuctionRpc\\GPBMetadata\xea\x02\x13InjectiveAuctionRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_auction_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective_auction_rpcB\030InjectiveAuctionRpcProtoP\001Z\030/injective_auction_rpcpb\242\002\003IXX\252\002\023InjectiveAuctionRpc\312\002\023InjectiveAuctionRpc\342\002\037InjectiveAuctionRpc\\GPBMetadata\352\002\023InjectiveAuctionRpc'
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_start=63
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_end=109
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_start=112
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_end=243
  _globals['_AUCTION']._serialized_start=246
  _globals['_AUCTION']._serialized_end=468
  _globals['_COIN']._serialized_start=470
  _globals['_COIN']._serialized_end=551
  _globals['_BID']._serialized_start=553
  _globals['_BID']._serialized_end=636
  _globals['_AUCTIONSREQUEST']._serialized_start=638
  _globals['_AUCTIONSREQUEST']._serialized_end=655
  _globals['_AUCTIONSRESPONSE']._serialized_start=657
  _globals['_AUCTIONSRESPONSE']._serialized_end=735
  _globals['_STREAMBIDSREQUEST']._serialized_start=737
  _globals['_STREAMBIDSREQUEST']._serialized_end=756
  _globals['_STREAMBIDSRESPONSE']._serialized_start=758
  _globals['_STREAMBIDSRESPONSE']._serialized_end=885
  _globals['_INJBURNTENDPOINTREQUEST']._serialized_start=887
  _globals['_INJBURNTENDPOINTREQUEST']._serialized_end=912
  _globals['_INJBURNTENDPOINTRESPONSE']._serialized_start=914
  _globals['_INJBURNTENDPOINTRESPONSE']._serialized_end=980
  _globals['_INJECTIVEAUCTIONRPC']._serialized_start=983
  _globals['_INJECTIVEAUCTIONRPC']._serialized_end=1429
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/genesis/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from pyinjective.proto.ibc.applications.interchain_accounts.host.v1 import host_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_host_dot_v1_dot_host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=ibc/applications/interchain_accounts/genesis/v1/genesis.proto\x12/ibc.applications.interchain_accounts.genesis.v1\x1a\x14gogoproto/gogo.proto\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x37ibc/applications/interchain_accounts/host/v1/host.proto\"\x8f\x02\n\x0cGenesisState\x12\x87\x01\n\x18\x63ontroller_genesis_state\x18\x01 \x01(\x0b\x32G.ibc.applications.interchain_accounts.genesis.v1.ControllerGenesisStateB\x04\xc8\xde\x1f\x00R\x16\x63ontrollerGenesisState\x12u\n\x12host_genesis_state\x18\x02 \x01(\x0b\x32\x41.ibc.applications.interchain_accounts.genesis.v1.HostGenesisStateB\x04\xc8\xde\x1f\x00R\x10hostGenesisState\"\xfd\x02\n\x16\x43ontrollerGenesisState\x12m\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32>.ibc.applications.interchain_accounts.genesis.v1.ActiveChannelB\x04\xc8\xde\x1f\x00R\x0e\x61\x63tiveChannels\x12\x83\x01\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32L.ibc.applications.interchain_accounts.genesis.v1.RegisteredInterchainAccountB\x04\xc8\xde\x1f\x00R\x12interchainAccounts\x12\x14\n\x05ports\x18\x03 \x03(\tR\x05ports\x12X\n\x06params\x18\x04 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\xef\x02\n\x10HostGenesisState\x12m\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32>.ibc.applications.interchain_accounts.genesis.v1.ActiveChannelB\x04\xc8\xde\x1f\x00R\x0e\x61\x63tiveChannels\x12\x83\x01\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32L.ibc.applications.interchain_accounts.genesis.v1.RegisteredInterchainAccountB\x04\xc8\xde\x1f\x00R\x12interchainAccounts\x12\x12\n\x04port\x18\x03 \x01(\tR\x04port\x12R\n\x06params\x18\x04 \x01(\x0b\x32\x34.ibc.applications.interchain_accounts.host.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\xa0\x01\n\rActiveChannel\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\x12\x17\n\x07port_id\x18\x02 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x03 \x01(\tR\tchannelId\x12\x32\n\x15is_middleware_enabled\x18\x04 \x01(\x08R\x13isMiddlewareEnabled\"\x84\x01\n\x1bRegisteredInterchainAccount\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\x12\x17\n\x07port_id\x18\x02 \x01(\tR\x06portId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tR\x0e\x61\x63\x63ountAddressB\xef\x02\n3com.ibc.applications.interchain_accounts.genesis.v1B\x0cGenesisProtoP\x01ZMgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/genesis/types\xa2\x02\x04IAIG\xaa\x02.Ibc.Applications.InterchainAccounts.Genesis.V1\xca\x02.Ibc\\Applications\\InterchainAccounts\\Genesis\\V1\xe2\x02:Ibc\\Applications\\InterchainAccounts\\Genesis\\V1\\GPBMetadata\xea\x02\x32Ibc::Applications::InterchainAccounts::Genesis::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.genesis.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3com.ibc.applications.interchain_accounts.genesis.v1B\014GenesisProtoP\001ZMgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/genesis/types\242\002\004IAIG\252\002.Ibc.Applications.InterchainAccounts.Genesis.V1\312\002.Ibc\\Applications\\InterchainAccounts\\Genesis\\V1\342\002:Ibc\\Applications\\InterchainAccounts\\Genesis\\V1\\GPBMetadata\352\0022Ibc::Applications::InterchainAccounts::Genesis::V1'
  _globals['_GENESISSTATE'].fields_by_name['controller_genesis_state']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['controller_genesis_state']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['host_genesis_state']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['host_genesis_state']._serialized_options = b'\310\336\037\000'
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['active_channels']._loaded_options = None
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['active_channels']._serialized_options = b'\310\336\037\000'
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['interchain_accounts']._loaded_options = None
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000'
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_CONTROLLERGENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_HOSTGENESISSTATE'].fields_by_name['active_channels']._loaded_options = None
  _globals['_HOSTGENESISSTATE'].fields_by_name['active_channels']._serialized_options = b'\310\336\037\000'
  _globals['_HOSTGENESISSTATE'].fields_by_name['interchain_accounts']._loaded_options = None
  _globals['_HOSTGENESISSTATE'].fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000'
  _globals['_HOSTGENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_HOSTGENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=263
  _globals['_GENESISSTATE']._serialized_end=534
  _globals['_CONTROLLERGENESISSTATE']._serialized_start=537
  _globals['_CONTROLLERGENESISSTATE']._serialized_end=918
  _globals['_HOSTGENESISSTATE']._serialized_start=921
  _globals['_HOSTGENESISSTATE']._serialized_end=1288
  _globals['_ACTIVECHANNEL']._serialized_start=1291
  _globals['_ACTIVECHANNEL']._serialized_end=1451
  _globals['_REGISTEREDINTERCHAINACCOUNT']._serialized_start=1454
  _globals['_REGISTEREDINTERCHAINACCOUNT']._serialized_end=1586
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/module/v1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/authz/module/v1/module.proto\x12\x16\x63osmos.authz.module.v1\x1a cosmos/app/v1alpha1/module.proto\"6\n\x06Module:,\xba\xc0\x96\xda\x01&\n$github.com/cosmos/cosmos-sdk/x/authzB\xa4\x01\n\x1a\x63om.cosmos.authz.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43\x41M\xaa\x02\x16\x43osmos.Authz.Module.V1\xca\x02\x16\x43osmos\\Authz\\Module\\V1\xe2\x02\"Cosmos\\Authz\\Module\\V1\\GPBMetadata\xea\x02\x19\x43osmos::Authz::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cosmos.authz.module.v1B\013ModuleProtoP\001\242\002\003CAM\252\002\026Cosmos.Authz.Module.V1\312\002\026Cosmos\\Authz\\Module\\V1\342\002\"Cosmos\\Authz\\Module\\V1\\GPBMetadata\352\002\031Cosmos::Authz::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001&\n$github.com/cosmos/cosmos-sdk/x/authz'
  _globals['_MODULE']._serialized_start=97
  _globals['_MODULE']._serialized_end=151
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.stream.v2 import query_pb2 as injective_dot_stream_dot_v2_dot_query__pb2


class StreamStub(object):
    """ChainStream defines the gRPC streaming service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamV2 = channel.unary_stream(
                '/injective.stream.v2.Stream/StreamV2',
                request_serializer=injective_dot_stream_dot_v2_dot_query__pb2.StreamRequest.SerializeToString,
                response_deserializer=injective_dot_stream_dot_v2_dot_query__pb2.StreamResponse.FromString,
                _registered_method=True)


class StreamServicer(object):
    """ChainStream defines the gRPC streaming service.
    """

    def StreamV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamV2': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamV2,
                    request_deserializer=injective_dot_stream_dot_v2_dot_query__pb2.StreamRequest.FromString,
                    response_serializer=injective_dot_stream_dot_v2_dot_query__pb2.StreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.stream.v2.Stream', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.stream.v2.Stream', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Stream(object):
    """ChainStream defines the gRPC streaming service.
    """

    @staticmethod
    def StreamV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/injective.stream.v2.Stream/StreamV2',
            injective_dot_stream_dot_v2_dot_query__pb2.StreamRequest.SerializeToString,
            injective_dot_stream_dot_v2_dot_query__pb2.StreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.channel.v1 import upgrade_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_upgrade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/channel/v1/query.proto\x12\x13ibc.core.channel.v1\x1a\x1fibc/core/client/v1/client.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\x1a!ibc/core/channel/v1/upgrade.proto\"M\n\x13QueryChannelRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"\xa9\x01\n\x14QueryChannelResponse\x12\x36\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelR\x07\x63hannel\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"^\n\x14QueryChannelsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xde\x01\n\x15QueryChannelsResponse\x12\x42\n\x08\x63hannels\x18\x01 \x03(\x0b\x32&.ibc.core.channel.v1.IdentifiedChannelR\x08\x63hannels\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\x12\x38\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\"\x88\x01\n\x1eQueryConnectionChannelsRequest\x12\x1e\n\nconnection\x18\x01 \x01(\tR\nconnection\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xe8\x01\n\x1fQueryConnectionChannelsResponse\x12\x42\n\x08\x63hannels\x18\x01 \x03(\x0b\x32&.ibc.core.channel.v1.IdentifiedChannelR\x08\x63hannels\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\x12\x38\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\"X\n\x1eQueryChannelClientStateRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"\xdf\x01\n\x1fQueryChannelClientStateResponse\x12\x61\n\x17identified_client_state\x18\x01 \x01(\x0b\x32).ibc.core.client.v1.IdentifiedClientStateR\x15identifiedClientState\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"\xad\x01\n!QueryChannelConsensusStateRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\'\n\x0frevision_number\x18\x03 \x01(\x04R\x0erevisionNumber\x12\'\n\x0frevision_height\x18\x04 \x01(\x04R\x0erevisionHeight\"\xdb\x01\n\"QueryChannelConsensusStateResponse\x12=\n\x0f\x63onsensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0e\x63onsensusState\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\x12\x14\n\x05proof\x18\x03 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"r\n\x1cQueryPacketCommitmentRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\"\x9a\x01\n\x1dQueryPacketCommitmentResponse\x12\x1e\n\ncommitment\x18\x01 \x01(\x0cR\ncommitment\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"\x9f\x01\n\x1dQueryPacketCommitmentsRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x46\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xe7\x01\n\x1eQueryPacketCommitmentsResponse\x12\x42\n\x0b\x63ommitments\x18\x01 \x03(\x0b\x32 .ibc.core.channel.v1.PacketStateR\x0b\x63ommitments\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\x12\x38\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\"o\n\x19QueryPacketReceiptRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\"\x93\x01\n\x1aQueryPacketReceiptResponse\x12\x1a\n\x08received\x18\x02 \x01(\x08R\x08received\x12\x14\n\x05proof\x18\x03 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"w\n!QueryPacketAcknowledgementRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\"\xa9\x01\n\"QueryPacketAcknowledgementResponse\x12(\n\x0f\x61\x63knowledgement\x18\x01 \x01(\x0cR\x0f\x61\x63knowledgement\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"\xe4\x01\n\"QueryPacketAcknowledgementsRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x46\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\x12>\n\x1bpacket_commitment_sequences\x18\x04 \x03(\x04R\x19packetCommitmentSequences\"\xf6\x01\n#QueryPacketAcknowledgementsResponse\x12L\n\x10\x61\x63knowledgements\x18\x01 \x03(\x0b\x32 .ibc.core.channel.v1.PacketStateR\x10\x61\x63knowledgements\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\x12\x38\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\"\x97\x01\n\x1dQueryUnreceivedPacketsRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12>\n\x1bpacket_commitment_sequences\x18\x03 \x03(\x04R\x19packetCommitmentSequences\"x\n\x1eQueryUnreceivedPacketsResponse\x12\x1c\n\tsequences\x18\x01 \x03(\x04R\tsequences\x12\x38\n\x06height\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\"\x86\x01\n\x1aQueryUnreceivedAcksRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x30\n\x14packet_ack_sequences\x18\x03 \x03(\x04R\x12packetAckSequences\"u\n\x1bQueryUnreceivedAcksResponse\x12\x1c\n\tsequences\x18\x01 \x03(\x04R\tsequences\x12\x38\n\x06height\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\"Y\n\x1fQueryNextSequenceReceiveRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"\xb1\x01\n QueryNextSequenceReceiveResponse\x12\x32\n\x15next_sequence_receive\x18\x01 \x01(\x04R\x13nextSequenceReceive\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"V\n\x1cQueryNextSequenceSendRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"\xa8\x01\n\x1dQueryNextSequenceSendResponse\x12,\n\x12next_sequence_send\x18\x01 \x01(\x04R\x10nextSequenceSend\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"R\n\x18QueryUpgradeErrorRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"\xc4\x01\n\x19QueryUpgradeErrorResponse\x12L\n\rerror_receipt\x18\x01 \x01(\x0b\x32!.ibc.core.channel.v1.ErrorReceiptB\x04\xc8\xde\x1f\x00R\x0c\x65rrorReceipt\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"M\n\x13QueryUpgradeRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"\xaf\x01\n\x14QueryUpgradeResponse\x12<\n\x07upgrade\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x07upgrade\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"\x1b\n\x19QueryChannelParamsRequest\"Q\n\x1aQueryChannelParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.ParamsR\x06params2\xe5\x1b\n\x05Query\x12\xa2\x01\n\x07\x43hannel\x12(.ibc.core.channel.v1.QueryChannelRequest\x1a).ibc.core.channel.v1.QueryChannelResponse\"B\x82\xd3\xe4\x93\x02<\x12:/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}\x12\x88\x01\n\x08\x43hannels\x12).ibc.core.channel.v1.QueryChannelsRequest\x1a*.ibc.core.channel.v1.QueryChannelsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/ibc/core/channel/v1/channels\x12\xbf\x01\n\x12\x43onnectionChannels\x12\x33.ibc.core.channel.v1.QueryConnectionChannelsRequest\x1a\x34.ibc.core.channel.v1.QueryConnectionChannelsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/ibc/core/channel/v1/connections/{connection}/channels\x12\xd0\x01\n\x12\x43hannelClientState\x12\x33.ibc.core.channel.v1.QueryChannelClientStateRequest\x1a\x34.ibc.core.channel.v1.QueryChannelClientStateResponse\"O\x82\xd3\xe4\x93\x02I\x12G/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/client_state\x12\x92\x02\n\x15\x43hannelConsensusState\x12\x36.ibc.core.channel.v1.QueryChannelConsensusStateRequest\x1a\x37.ibc.core.channel.v1.QueryChannelConsensusStateResponse\"\x87\x01\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/consensus_state/revision/{revision_number}/height/{revision_height}\x12\xdb\x01\n\x10PacketCommitment\x12\x31.ibc.core.channel.v1.QueryPacketCommitmentRequest\x1a\x32.ibc.core.channel.v1.QueryPacketCommitmentResponse\"`\x82\xd3\xe4\x93\x02Z\x12X/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{sequence}\x12\xd3\x01\n\x11PacketCommitments\x12\x32.ibc.core.channel.v1.QueryPacketCommitmentsRequest\x1a\x33.ibc.core.channel.v1.QueryPacketCommitmentsResponse\"U\x82\xd3\xe4\x93\x02O\x12M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments\x12\xcf\x01\n\rPacketReceipt\x12..ibc.core.channel.v1.QueryPacketReceiptRequest\x1a/.ibc.core.channel.v1.QueryPacketReceiptResponse\"]\x82\xd3\xe4\x93\x02W\x12U/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_receipts/{sequence}\x12\xe3\x01\n\x15PacketAcknowledgement\x12\x36.ibc.core.channel.v1.QueryPacketAcknowledgementRequest\x1a\x37.ibc.core.channel.v1.QueryPacketAcknowledgementResponse\"Y\x82\xd3\xe4\x93\x02S\x12Q/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acks/{sequence}\x12\xe7\x01\n\x16PacketAcknowledgements\x12\x37.ibc.core.channel.v1.QueryPacketAcknowledgementsRequest\x1a\x38.ibc.core.channel.v1.QueryPacketAcknowledgementsResponse\"Z\x82\xd3\xe4\x93\x02T\x12R/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acknowledgements\x12\x86\x02\n\x11UnreceivedPackets\x12\x32.ibc.core.channel.v1.QueryUnreceivedPacketsRequest\x1a\x33.ibc.core.channel.v1.QueryUnreceivedPacketsResponse\"\x87\x01\x82\xd3\xe4\x93\x02\x80\x01\x12~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_commitment_sequences}/unreceived_packets\x12\xf1\x01\n\x0eUnreceivedAcks\x12/.ibc.core.channel.v1.QueryUnreceivedAcksRequest\x1a\x30.ibc.core.channel.v1.QueryUnreceivedAcksResponse\"|\x82\xd3\xe4\x93\x02v\x12t/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_ack_sequences}/unreceived_acks\x12\xd4\x01\n\x13NextSequenceReceive\x12\x34.ibc.core.channel.v1.QueryNextSequenceReceiveRequest\x1a\x35.ibc.core.channel.v1.QueryNextSequenceReceiveResponse\"P\x82\xd3\xe4\x93\x02J\x12H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequence\x12\xd0\x01\n\x10NextSequenceSend\x12\x31.ibc.core.channel.v1.QueryNextSequenceSendRequest\x1a\x32.ibc.core.channel.v1.QueryNextSequenceSendResponse\"U\x82\xd3\xe4\x93\x02O\x12M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequence_send\x12\xbf\x01\n\x0cUpgradeError\x12-.ibc.core.channel.v1.QueryUpgradeErrorRequest\x1a..ibc.core.channel.v1.QueryUpgradeErrorResponse\"P\x82\xd3\xe4\x93\x02J\x12H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/upgrade_error\x12\xaa\x01\n\x07Upgrade\x12(.ibc.core.channel.v1.QueryUpgradeRequest\x1a).ibc.core.channel.v1.QueryUpgradeResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/upgrade\x12\x95\x01\n\rChannelParams\x12..ibc.core.channel.v1.QueryChannelParamsRequest\x1a/.ibc.core.channel.v1.QueryChannelParamsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/ibc/core/channel/v1/paramsB\xcf\x01\n\x17\x63om.ibc.core.channel.v1B\nQueryProtoP\x01Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\xa2\x02\x03ICC\xaa\x02\x13Ibc.Core.Channel.V1\xca\x02\x13Ibc\\Core\\Channel\\V1\xe2\x02\x1fIbc\\Core\\Channel\\V1\\GPBMetadata\xea\x02\x16Ibc::Core::Channel::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.ibc.core.channel.v1B\nQueryProtoP\001Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\242\002\003ICC\252\002\023Ibc.Core.Channel.V1\312\002\023Ibc\\Core\\Channel\\V1\342\002\037Ibc\\Core\\Channel\\V1\\GPBMetadata\352\002\026Ibc::Core::Channel::V1'
  _globals['_QUERYCHANNELRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCHANNELRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCHANNELSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYCHANNELSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONNECTIONCHANNELSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYCONNECTIONCHANNELSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCHANNELCLIENTSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCHANNELCLIENTSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCHANNELCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCHANNELCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPACKETCOMMITMENTRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYPACKETCOMMITMENTRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPACKETCOMMITMENTSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYPACKETCOMMITMENTSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPACKETRECEIPTRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYPACKETRECEIPTRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPACKETACKNOWLEDGEMENTRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYPACKETACKNOWLEDGEMENTRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPACKETACKNOWLEDGEMENTSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYPACKETACKNOWLEDGEMENTSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUNRECEIVEDPACKETSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYUNRECEIVEDPACKETSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUNRECEIVEDACKSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYUNRECEIVEDACKSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYNEXTSEQUENCERECEIVERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYNEXTSEQUENCERECEIVERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYNEXTSEQUENCESENDRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYNEXTSEQUENCESENDRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUPGRADEERRORRESPONSE'].fields_by_name['error_receipt']._loaded_options = None
  _globals['_QUERYUPGRADEERRORRESPONSE'].fields_by_name['error_receipt']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUPGRADEERRORRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYUPGRADEERRORRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUPGRADERESPONSE'].fields_by_name['upgrade']._loaded_options = None
  _globals['_QUERYUPGRADERESPONSE'].fields_by_name['upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUPGRADERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYUPGRADERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Channel']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Channel']._serialized_options = b'\202\323\344\223\002<\022:/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}'
  _globals['_QUERY'].methods_by_name['Channels']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Channels']._serialized_options = b'\202\323\344\223\002\037\022\035/ibc/core/channel/v1/channels'
  _globals['_QUERY'].methods_by_name['ConnectionChannels']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConnectionChannels']._serialized_options = b'\202\323\344\223\0028\0226/ibc/core/channel/v1/connections/{connection}/channels'
  _globals['_QUERY'].methods_by_name['ChannelClientState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ChannelClientState']._serialized_options = b'\202\323\344\223\002I\022G/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/client_state'
  _globals['_QUERY'].methods_by_name['ChannelConsensusState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ChannelConsensusState']._serialized_options = b'\202\323\344\223\002\200\001\022~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/consensus_state/revision/{revision_number}/height/{revision_height}'
  _globals['_QUERY'].methods_by_name['PacketCommitment']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PacketCommitment']._serialized_options = b'\202\323\344\223\002Z\022X/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{sequence}'
  _globals['_QUERY'].methods_by_name['PacketCommitments']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PacketCommitments']._serialized_options = b'\202\323\344\223\002O\022M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments'
  _globals['_QUERY'].methods_by_name['PacketReceipt']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PacketReceipt']._serialized_options = b'\202\323\344\223\002W\022U/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_receipts/{sequence}'
  _globals['_QUERY'].methods_by_name['PacketAcknowledgement']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PacketAcknowledgement']._serialized_options = b'\202\323\344\223\002S\022Q/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acks/{sequence}'
  _globals['_QUERY'].methods_by_name['PacketAcknowledgements']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PacketAcknowledgements']._serialized_options = b'\202\323\344\223\002T\022R/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_acknowledgements'
  _globals['_QUERY'].methods_by_name['UnreceivedPackets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UnreceivedPackets']._serialized_options = b'\202\323\344\223\002\200\001\022~/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_commitment_sequences}/unreceived_packets'
  _globals['_QUERY'].methods_by_name['UnreceivedAcks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UnreceivedAcks']._serialized_options = b'\202\323\344\223\002v\022t/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/packet_commitments/{packet_ack_sequences}/unreceived_acks'
  _globals['_QUERY'].methods_by_name['NextSequenceReceive']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NextSequenceReceive']._serialized_options = b'\202\323\344\223\002J\022H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequence'
  _globals['_QUERY'].methods_by_name['NextSequenceSend']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NextSequenceSend']._serialized_options = b'\202\323\344\223\002O\022M/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/next_sequence_send'
  _globals['_QUERY'].methods_by_name['UpgradeError']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UpgradeError']._serialized_options = b'\202\323\344\223\002J\022H/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/upgrade_error'
  _globals['_QUERY'].methods_by_name['Upgrade']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Upgrade']._serialized_options = b'\202\323\344\223\002D\022B/ibc/core/channel/v1/channels/{channel_id}/ports/{port_id}/upgrade'
  _globals['_QUERY'].methods_by_name['ChannelParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ChannelParams']._serialized_options = b'\202\323\344\223\002\035\022\033/ibc/core/channel/v1/params'
  _globals['_QUERYCHANNELREQUEST']._serialized_start=282
  _globals['_QUERYCHANNELREQUEST']._serialized_end=359
  _globals['_QUERYCHANNELRESPONSE']._serialized_start=362
  _globals['_QUERYCHANNELRESPONSE']._serialized_end=531
  _globals['_QUERYCHANNELSREQUEST']._serialized_start=533
  _globals['_QUERYCHANNELSREQUEST']._serialized_end=627
  _globals['_QUERYCHANNELSRESPONSE']._serialized_start=630
  _globals['_QUERYCHANNELSRESPONSE']._serialized_end=852
  _globals['_QUERYCONNECTIONCHANNELSREQUEST']._serialized_start=855
  _globals['_QUERYCONNECTIONCHANNELSREQUEST']._serialized_end=991
  _globals['_QUERYCONNECTIONCHANNELSRESPONSE']._serialized_start=994
  _globals['_QUERYCONNECTIONCHANNELSRESPONSE']._serialized_end=1226
  _globals['_QUERYCHANNELCLIENTSTATEREQUEST']._serialized_start=1228
  _globals['_QUERYCHANNELCLIENTSTATEREQUEST']._serialized_end=1316
  _globals['_QUERYCHANNELCLIENTSTATERESPONSE']._serialized_start=1319
  _globals['_QUERYCHANNELCLIENTSTATERESPONSE']._serialized_end=1542
  _globals['_QUERYCHANNELCONSENSUSSTATEREQUEST']._serialized_start=1545
  _globals['_QUERYCHANNELCONSENSUSSTATEREQUEST']._serialized_end=1718
  _globals['_QUERYCHANNELCONSENSUSSTATERESPONSE']._serialized_start=1721
  _globals['_QUERYCHANNELCONSENSUSSTATERESPONSE']._serialized_end=1940
  _globals['_QUERYPACKETCOMMITMENTREQUEST']._serialized_start=1942
  _globals['_QUERYPACKETCOMMITMENTREQUEST']._serialized_end=2056
  _globals['_QUERYPACKETCOMMITMENTRESPONSE']._serialized_start=2059
  _globals['_QUERYPACKETCOMMITMENTRESPONSE']._serialized_end=2213
  _globals['_QUERYPACKETCOMMITMENTSREQUEST']._serialized_start=2216
  _globals['_QUERYPACKETCOMMITMENTSREQUEST']._serialized_end=2375
  _globals['_QUERYPACKETCOMMITMENTSRESPONSE']._serialized_start=2378
  _globals['_QUERYPACKETCOMMITMENTSRESPONSE']._serialized_end=2609
  _globals['_QUERYPACKETRECEIPTREQUEST']._serialized_start=2611
  _globals['_QUERYPACKETRECEIPTREQUEST']._serialized_end=2722
  _globals['_QUERYPACKETRECEIPTRESPONSE']._serialized_start=2725
  _globals['_QUERYPACKETRECEIPTRESPONSE']._serialized_end=2872
  _globals['_QUERYPACKETACKNOWLEDGEMENTREQUEST']._serialized_start=2874
  _globals['_QUERYPACKETACKNOWLEDGEMENTREQUEST']._serialized_end=2993
  _globals['_QUERYPACKETACKNOWLEDGEMENTRESPONSE']._serialized_start=2996
  _globals['_QUERYPACKETACKNOWLEDGEMENTRESPONSE']._serialized_end=3165
  _globals['_QUERYPACKETACKNOWLEDGEMENTSREQUEST']._serialized_start=3168
  _globals['_QUERYPACKETACKNOWLEDGEMENTSREQUEST']._serialized_end=3396
  _globals['_QUERYPACKETACKNOWLEDGEMENTSRESPONSE']._serialized_start=3399
  _globals['_QUERYPACKETACKNOWLEDGEMENTSRESPONSE']._serialized_end=3645
  _globals['_QUERYUNRECEIVEDPACKETSREQUEST']._serialized_start=3648
  _globals['_QUERYUNRECEIVEDPACKETSREQUEST']._serialized_end=3799
  _globals['_QUERYUNRECEIVEDPACKETSRESPONSE']._serialized_start=3801
  _globals['_QUERYUNRECEIVEDPACKETSRESPONSE']._serialized_end=3921
  _globals['_QUERYUNRECEIVEDACKSREQUEST']._serialized_start=3924
  _globals['_QUERYUNRECEIVEDACKSREQUEST']._serialized_end=4058
  _globals['_QUERYUNRECEIVEDACKSRESPONSE']._serialized_start=4060
  _globals['_QUERYUNRECEIVEDACKSRESPONSE']._serialized_end=4177
  _globals['_QUERYNEXTSEQUENCERECEIVEREQUEST']._serialized_start=4179
  _globals['_QUERYNEXTSEQUENCERECEIVEREQUEST']._serialized_end=4268
  _globals['_QUERYNEXTSEQUENCERECEIVERESPONSE']._serialized_start=4271
  _globals['_QUERYNEXTSEQUENCERECEIVERESPONSE']._serialized_end=4448
  _globals['_QUERYNEXTSEQUENCESENDREQUEST']._serialized_start=4450
  _globals['_QUERYNEXTSEQUENCESENDREQUEST']._serialized_end=4536
  _globals['_QUERYNEXTSEQUENCESENDRESPONSE']._serialized_start=4539
  _globals['_QUERYNEXTSEQUENCESENDRESPONSE']._serialized_end=4707
  _globals['_QUERYUPGRADEERRORREQUEST']._serialized_start=4709
  _globals['_QUERYUPGRADEERRORREQUEST']._serialized_end=4791
  _globals['_QUERYUPGRADEERRORRESPONSE']._serialized_start=4794
  _globals['_QUERYUPGRADEERRORRESPONSE']._serialized_end=4990
  _globals['_QUERYUPGRADEREQUEST']._serialized_start=4992
  _globals['_QUERYUPGRADEREQUEST']._serialized_end=5069
  _globals['_QUERYUPGRADERESPONSE']._serialized_start=5072
  _globals['_QUERYUPGRADERESPONSE']._serialized_end=5247
  _globals['_QUERYCHANNELPARAMSREQUEST']._serialized_start=5249
  _globals['_QUERYCHANNELPARAMSREQUEST']._serialized_end=5276
  _globals['_QUERYCHANNELPARAMSRESPONSE']._serialized_start=5278
  _globals['_QUERYCHANNELPARAMSRESPONSE']._serialized_end=5359
  _globals['_QUERY']._serialized_start=5362
  _globals['_QUERY']._serialized_end=8919
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/channel.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/core/channel/v1/channel.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\"\xb4\x02\n\x07\x43hannel\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.StateR\x05state\x12\x36\n\x08ordering\x18\x02 \x01(\x0e\x32\x1a.ibc.core.channel.v1.OrderR\x08ordering\x12K\n\x0c\x63ounterparty\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12\'\n\x0f\x63onnection_hops\x18\x04 \x03(\tR\x0e\x63onnectionHops\x12\x18\n\x07version\x18\x05 \x01(\tR\x07version\x12)\n\x10upgrade_sequence\x18\x06 \x01(\x04R\x0fupgradeSequence:\x04\x88\xa0\x1f\x00\"\xf6\x02\n\x11IdentifiedChannel\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.StateR\x05state\x12\x36\n\x08ordering\x18\x02 \x01(\x0e\x32\x1a.ibc.core.channel.v1.OrderR\x08ordering\x12K\n\x0c\x63ounterparty\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12\'\n\x0f\x63onnection_hops\x18\x04 \x03(\tR\x0e\x63onnectionHops\x12\x18\n\x07version\x18\x05 \x01(\tR\x07version\x12\x17\n\x07port_id\x18\x06 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x07 \x01(\tR\tchannelId\x12)\n\x10upgrade_sequence\x18\x08 \x01(\x04R\x0fupgradeSequence:\x04\x88\xa0\x1f\x00\"L\n\x0c\x43ounterparty\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId:\x04\x88\xa0\x1f\x00\"\xd8\x02\n\x06Packet\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x1f\n\x0bsource_port\x18\x02 \x01(\tR\nsourcePort\x12%\n\x0esource_channel\x18\x03 \x01(\tR\rsourceChannel\x12)\n\x10\x64\x65stination_port\x18\x04 \x01(\tR\x0f\x64\x65stinationPort\x12/\n\x13\x64\x65stination_channel\x18\x05 \x01(\tR\x12\x64\x65stinationChannel\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12G\n\x0etimeout_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\rtimeoutHeight\x12+\n\x11timeout_timestamp\x18\x08 \x01(\x04R\x10timeoutTimestamp:\x04\x88\xa0\x1f\x00\"{\n\x0bPacketState\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\x12\x12\n\x04\x64\x61ta\x18\x04 \x01(\x0cR\x04\x64\x61ta:\x04\x88\xa0\x1f\x00\"d\n\x08PacketId\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence:\x04\x88\xa0\x1f\x00\"O\n\x0f\x41\x63knowledgement\x12\x18\n\x06result\x18\x15 \x01(\x0cH\x00R\x06result\x12\x16\n\x05\x65rror\x18\x16 \x01(\tH\x00R\x05\x65rrorB\n\n\x08response\"a\n\x07Timeout\x12\x38\n\x06height\x18\x01 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\"U\n\x06Params\x12K\n\x0fupgrade_timeout\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.TimeoutB\x04\xc8\xde\x1f\x00R\x0eupgradeTimeout*\x85\x02\n\x05State\x12\x36\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x12\x1c\n\x0cSTATE_CLOSED\x10\x04\x1a\n\x8a\x9d \x06\x43LOSED\x12 \n\x0eSTATE_FLUSHING\x10\x05\x1a\x0c\x8a\x9d \x08\x46LUSHING\x12*\n\x13STATE_FLUSHCOMPLETE\x10\x06\x1a\x11\x8a\x9d \rFLUSHCOMPLETE\x1a\x04\x88\xa3\x1e\x00*w\n\x05Order\x12$\n\x16ORDER_NONE_UNSPECIFIED\x10\x00\x1a\x08\x8a\x9d \x04NONE\x12\"\n\x0fORDER_UNORDERED\x10\x01\x1a\r\x8a\x9d \tUNORDERED\x12\x1e\n\rORDER_ORDERED\x10\x02\x1a\x0b\x8a\x9d \x07ORDERED\x1a\x04\x88\xa3\x1e\x00\x42\xd1\x01\n\x17\x63om.ibc.core.channel.v1B\x0c\x43hannelProtoP\x01Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\xa2\x02\x03ICC\xaa\x02\x13Ibc.Core.Channel.V1\xca\x02\x13Ibc\\Core\\Channel\\V1\xe2\x02\x1fIbc\\Core\\Channel\\V1\\GPBMetadata\xea\x02\x16Ibc::Core::Channel::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.channel_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.ibc.core.channel.v1B\014ChannelProtoP\001Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\242\002\003ICC\252\002\023Ibc.Core.Channel.V1\312\002\023Ibc\\Core\\Channel\\V1\342\002\037Ibc\\Core\\Channel\\V1\\GPBMetadata\352\002\026Ibc::Core::Channel::V1'
  _globals['_STATE']._loaded_options = None
  _globals['_STATE']._serialized_options = b'\210\243\036\000'
  _globals['_STATE'].values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \rUNINITIALIZED'
  _globals['_STATE'].values_by_name["STATE_INIT"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_INIT"]._serialized_options = b'\212\235 \004INIT'
  _globals['_STATE'].values_by_name["STATE_TRYOPEN"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_TRYOPEN"]._serialized_options = b'\212\235 \007TRYOPEN'
  _globals['_STATE'].values_by_name["STATE_OPEN"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_OPEN"]._serialized_options = b'\212\235 \004OPEN'
  _globals['_STATE'].values_by_name["STATE_CLOSED"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_CLOSED"]._serialized_options = b'\212\235 \006CLOSED'
  _globals['_STATE'].values_by_name["STATE_FLUSHING"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_FLUSHING"]._serialized_options = b'\212\235 \010FLUSHING'
  _globals['_STATE'].values_by_name["STATE_FLUSHCOMPLETE"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_FLUSHCOMPLETE"]._serialized_options = b'\212\235 \rFLUSHCOMPLETE'
  _globals['_ORDER']._loaded_options = None
  _globals['_ORDER']._serialized_options = b'\210\243\036\000'
  _globals['_ORDER'].values_by_name["ORDER_NONE_UNSPECIFIED"]._loaded_options = None
  _globals['_ORDER'].values_by_name["ORDER_NONE_UNSPECIFIED"]._serialized_options = b'\212\235 \004NONE'
  _globals['_ORDER'].values_by_name["ORDER_UNORDERED"]._loaded_options = None
  _globals['_ORDER'].values_by_name["ORDER_UNORDERED"]._serialized_options = b'\212\235 \tUNORDERED'
  _globals['_ORDER'].values_by_name["ORDER_ORDERED"]._loaded_options = None
  _globals['_ORDER'].values_by_name["ORDER_ORDERED"]._serialized_options = b'\212\235 \007ORDERED'
  _globals['_CHANNEL'].fields_by_name['counterparty']._loaded_options = None
  _globals['_CHANNEL'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_CHANNEL']._loaded_options = None
  _globals['_CHANNEL']._serialized_options = b'\210\240\037\000'
  _globals['_IDENTIFIEDCHANNEL'].fields_by_name['counterparty']._loaded_options = None
  _globals['_IDENTIFIEDCHANNEL'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_IDENTIFIEDCHANNEL']._loaded_options = None
  _globals['_IDENTIFIEDCHANNEL']._serialized_options = b'\210\240\037\000'
  _globals['_COUNTERPARTY']._loaded_options = None
  _globals['_COUNTERPARTY']._serialized_options = b'\210\240\037\000'
  _globals['_PACKET'].fields_by_name['timeout_height']._loaded_options = None
  _globals['_PACKET'].fields_by_name['timeout_height']._serialized_options = b'\310\336\037\000'
  _globals['_PACKET']._loaded_options = None
  _globals['_PACKET']._serialized_options = b'\210\240\037\000'
  _globals['_PACKETSTATE']._loaded_options = None
  _globals['_PACKETSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_PACKETID']._loaded_options = None
  _globals['_PACKETID']._serialized_options = b'\210\240\037\000'
  _globals['_TIMEOUT'].fields_by_name['height']._loaded_options = None
  _globals['_TIMEOUT'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_PARAMS'].fields_by_name['upgrade_timeout']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['upgrade_timeout']._serialized_options = b'\310\336\037\000'
  _globals['_STATE']._serialized_start=1721
  _globals['_STATE']._serialized_end=1982
  _globals['_ORDER']._serialized_start=1984
  _globals['_ORDER']._serialized_end=2103
  _globals['_CHANNEL']._serialized_start=114
  _globals['_CHANNEL']._serialized_end=422
  _globals['_IDENTIFIEDCHANNEL']._serialized_start=425
  _globals['_IDENTIFIEDCHANNEL']._serialized_end=799
  _globals['_COUNTERPARTY']._serialized_start=801
  _globals['_COUNTERPARTY']._serialized_end=877
  _globals['_PACKET']._serialized_start=880
  _globals['_PACKET']._serialized_end=1224
  _globals['_PACKETSTATE']._serialized_start=1226
  _globals['_PACKETSTATE']._serialized_end=1349
  _globals['_PACKETID']._serialized_start=1351
  _globals['_PACKETID']._serialized_end=1451
  _globals['_ACKNOWLEDGEMENT']._serialized_start=1453
  _globals['_ACKNOWLEDGEMENT']._serialized_end=1532
  _globals['_TIMEOUT']._serialized_start=1534
  _globals['_TIMEOUT']._serialized_end=1631
  _globals['_PARAMS']._serialized_start=1633
  _globals['_PARAMS']._serialized_end=1718
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ibc/applications/fee/v1/tx.proto\x12\x17ibc.applications.fee.v1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\xac\x01\n\x10MsgRegisterPayee\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x18\n\x07relayer\x18\x03 \x01(\tR\x07relayer\x12\x14\n\x05payee\x18\x04 \x01(\tR\x05payee:0\x88\xa0\x1f\x00\x82\xe7\xb0*\x07relayer\x8a\xe7\xb0*\x1b\x63osmos-sdk/MsgRegisterPayee\"\x1a\n\x18MsgRegisterPayeeResponse\"\xdd\x01\n\x1cMsgRegisterCounterpartyPayee\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x18\n\x07relayer\x18\x03 \x01(\tR\x07relayer\x12-\n\x12\x63ounterparty_payee\x18\x04 \x01(\tR\x11\x63ounterpartyPayee:<\x88\xa0\x1f\x00\x82\xe7\xb0*\x07relayer\x8a\xe7\xb0*\'cosmos-sdk/MsgRegisterCounterpartyPayee\"&\n$MsgRegisterCounterpartyPayeeResponse\"\x82\x02\n\x0fMsgPayPacketFee\x12\x39\n\x03\x66\x65\x65\x18\x01 \x01(\x0b\x32\x1c.ibc.applications.fee.v1.FeeB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x03\x66\x65\x65\x12$\n\x0esource_port_id\x18\x02 \x01(\tR\x0csourcePortId\x12*\n\x11source_channel_id\x18\x03 \x01(\tR\x0fsourceChannelId\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer\x12\x1a\n\x08relayers\x18\x05 \x03(\tR\x08relayers:.\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\x8a\xe7\xb0*\x1a\x63osmos-sdk/MsgPayPacketFee\"\x19\n\x17MsgPayPacketFeeResponse\"\xe4\x01\n\x14MsgPayPacketFeeAsync\x12\x45\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x08packetId\x12L\n\npacket_fee\x18\x02 \x01(\x0b\x32\".ibc.applications.fee.v1.PacketFeeB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tpacketFee:7\x88\xa0\x1f\x00\x82\xe7\xb0*\npacket_fee\x8a\xe7\xb0*\x1f\x63osmos-sdk/MsgPayPacketFeeAsync\"\x1e\n\x1cMsgPayPacketFeeAsyncResponse2\xf6\x03\n\x03Msg\x12m\n\rRegisterPayee\x12).ibc.applications.fee.v1.MsgRegisterPayee\x1a\x31.ibc.applications.fee.v1.MsgRegisterPayeeResponse\x12\x91\x01\n\x19RegisterCounterpartyPayee\x12\x35.ibc.applications.fee.v1.MsgRegisterCounterpartyPayee\x1a=.ibc.applications.fee.v1.MsgRegisterCounterpartyPayeeResponse\x12j\n\x0cPayPacketFee\x12(.ibc.applications.fee.v1.MsgPayPacketFee\x1a\x30.ibc.applications.fee.v1.MsgPayPacketFeeResponse\x12y\n\x11PayPacketFeeAsync\x12-.ibc.applications.fee.v1.MsgPayPacketFeeAsync\x1a\x35.ibc.applications.fee.v1.MsgPayPacketFeeAsyncResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xdc\x01\n\x1b\x63om.ibc.applications.fee.v1B\x07TxProtoP\x01Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\xa2\x02\x03IAF\xaa\x02\x17Ibc.Applications.Fee.V1\xca\x02\x17Ibc\\Applications\\Fee\\V1\xe2\x02#Ibc\\Applications\\Fee\\V1\\GPBMetadata\xea\x02\x1aIbc::Applications::Fee::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.ibc.applications.fee.v1B\007TxProtoP\001Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\242\002\003IAF\252\002\027Ibc.Applications.Fee.V1\312\002\027Ibc\\Applications\\Fee\\V1\342\002#Ibc\\Applications\\Fee\\V1\\GPBMetadata\352\002\032Ibc::Applications::Fee::V1'
  _globals['_MSGREGISTERPAYEE']._loaded_options = None
  _globals['_MSGREGISTERPAYEE']._serialized_options = b'\210\240\037\000\202\347\260*\007relayer\212\347\260*\033cosmos-sdk/MsgRegisterPayee'
  _globals['_MSGREGISTERCOUNTERPARTYPAYEE']._loaded_options = None
  _globals['_MSGREGISTERCOUNTERPARTYPAYEE']._serialized_options = b'\210\240\037\000\202\347\260*\007relayer\212\347\260*\'cosmos-sdk/MsgRegisterCounterpartyPayee'
  _globals['_MSGPAYPACKETFEE'].fields_by_name['fee']._loaded_options = None
  _globals['_MSGPAYPACKETFEE'].fields_by_name['fee']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGPAYPACKETFEE']._loaded_options = None
  _globals['_MSGPAYPACKETFEE']._serialized_options = b'\210\240\037\000\202\347\260*\006signer\212\347\260*\032cosmos-sdk/MsgPayPacketFee'
  _globals['_MSGPAYPACKETFEEASYNC'].fields_by_name['packet_id']._loaded_options = None
  _globals['_MSGPAYPACKETFEEASYNC'].fields_by_name['packet_id']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGPAYPACKETFEEASYNC'].fields_by_name['packet_fee']._loaded_options = None
  _globals['_MSGPAYPACKETFEEASYNC'].fields_by_name['packet_fee']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGPAYPACKETFEEASYNC']._loaded_options = None
  _globals['_MSGPAYPACKETFEEASYNC']._serialized_options = b'\210\240\037\000\202\347\260*\npacket_fee\212\347\260*\037cosmos-sdk/MsgPayPacketFeeAsync'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGREGISTERPAYEE']._serialized_start=198
  _globals['_MSGREGISTERPAYEE']._serialized_end=370
  _globals['_MSGREGISTERPAYEERESPONSE']._serialized_start=372
  _globals['_MSGREGISTERPAYEERESPONSE']._serialized_end=398
  _globals['_MSGREGISTERCOUNTERPARTYPAYEE']._serialized_start=401
  _globals['_MSGREGISTERCOUNTERPARTYPAYEE']._serialized_end=622
  _globals['_MSGREGISTERCOUNTERPARTYPAYEERESPONSE']._serialized_start=624
  _globals['_MSGREGISTERCOUNTERPARTYPAYEERESPONSE']._serialized_end=662
  _globals['_MSGPAYPACKETFEE']._serialized_start=665
  _globals['_MSGPAYPACKETFEE']._serialized_end=923
  _globals['_MSGPAYPACKETFEERESPONSE']._serialized_start=925
  _globals['_MSGPAYPACKETFEERESPONSE']._serialized_end=950
  _globals['_MSGPAYPACKETFEEASYNC']._serialized_start=953
  _globals['_MSGPAYPACKETFEEASYNC']._serialized_end=1181
  _globals['_MSGPAYPACKETFEEASYNCRESPONSE']._serialized_start=1183
  _globals['_MSGPAYPACKETFEEASYNCRESPONSE']._serialized_end=1213
  _globals['_MSG']._serialized_start=1216
  _globals['_MSG']._serialized_end=1718
# @@protoc_insertion_point(module_scope)
